<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  指定コメント情報の取得
 *
 *  @access public
 *  @param  integer $post_comment_id    コメントID
 */
function db_get_post_comment4delete($post_comment_id)
{
    $sql = 'SELECT post_comment_id, post_id, author_name, author_email, author_url, comment, r_datetime' .
            ' FROM pb_post_comments' .
            ' WHERE post_comment_id = ?';
    $params = array(
        intval($post_comment_id)
    );
    return pocket_db_getRow($sql, $params);
}

/**
 *  指定記事のコメント情報の取得
 *
 *  @access public
 *  @param  integer $post_id            記事ID
 */
function db_get_post_comments4post_comment($post_id)
{
    $sql = 'SELECT post_comment_id, post_id, author_name, author_email, author_url, comment, r_datetime' .
            ' FROM pb_post_comments' .
            ' WHERE post_id = ?' .
            ' AND is_approved = ?' .
            ' ORDER BY r_datetime';
    $params = array(
        intval($post_id),
        intval(true)
    );
    return pocket_db_getAll($sql, $params);
}

/**
 *  最新のコメント一覧情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_post_comments4latest_comment_list($page = 1, $page_size = 5)
{
    $sql = 'SELECT pc.post_comment_id, pc.post_id, pc.comment, pc.author_name, pc.r_datetime' .
            ' FROM pb_post_comments AS pc' .
            ' LEFT JOIN pb_posts AS p' .
                ' ON pc.post_id = p.post_id' .
            ' WHERE p.is_open = ?' .
            ' AND pc.is_approved = ?' .
            ' ORDER BY pc.r_datetime DESC';
    $params = array(
        intval(true),
        intval(true)
    );
    return pocket_db_getAllPage($sql, $page, $page_size, $params);
}

/**
 *  最新のコメント一覧情報（RSS用）の取得
 *
 *  @access public
 *  @param  integer $page_size          ページサイズ
 */
function db_get_post_comments4latest_comment_rss($page_size = 5)
{
    $sql = 'SELECT pc.post_comment_id, pc.post_id, p.subject AS title, pc.comment AS description, pc.author_name, pc.r_datetime' .
            ' FROM pb_post_comments AS pc' .
            ' LEFT JOIN pb_posts AS p' .
                ' ON pc.post_id = p.post_id' .
            ' WHERE p.is_open = ?' .
            ' AND pc.is_approved = ?' .
            ' ORDER BY pc.r_datetime DESC';
    $params = array(
        intval(true),
        intval(true)
    );
    return pocket_db_getAllPage($sql, 1, $page_size, $params);
}

/**
 *  未承認のコメント情報の取得
 *
 *  @access public
 *  @param  integer $page               ページ番号
 *  @param  integer $page_size          ページサイズ
 */
function db_get_post_comments4unapproved($page = 1, $page_size = 5)
{
    $sql = 'SELECT e.post_id, e.category_id, ca.category_name, e.subject,' .
            ' pc.post_comment_id, pc.author_name, pc.author_email, pc.author_url, pc.comment, pc.r_datetime' .
            ' FROM pb_posts AS e' .
            ' LEFT JOIN pb_post_comments AS pc' .
                ' ON e.post_id = pc.post_id' .
            ' LEFT JOIN pb_categories AS ca' .
                ' ON e.category_id = ca.category_id' .
            ' WHERE pc.is_approved = ?' .
            ' ORDER BY pc.r_datetime DESC';
    $params = array(
        intval(false)
    );
    return pocket_db_getAllPage($sql, $page, $page_size, $params);
}

/**
 *  未承認のコメント件数の取得
 *
 *  @access public
 */
function db_get_post_comments_count4unapproved()
{
    $sql = 'SELECT count(post_comment_id)' .
            ' FROM pb_post_comments' .
            ' WHERE is_approved = ?';
    $params = array(
        intval(false)
    );
    return pocket_db_getOne($sql, $params);
}

/**
 *  コメント情報の登録
 *
 *  @access public
 *  @param  integer $post_id            記事ID
 *  @param  integer $is_approved        承認フラグ
 *  @param  string  $author_name        名前
 *  @param  string  $author_email       メールアドレス
 *  @param  string  $author_url         URL
 *  @param  string  $comment            コメント
 */
function db_insert_post_comment($post_id, $is_approved, $author_name, $author_email, $author_url, $comment)
{
    $data = array(
        'post_id' => $post_id,
        'is_approved' => intval($is_approved),
        'author_name' => $author_name,
        'author_email' => $author_email,
        'author_url' => $author_url,
        'comment' => $comment,
        'r_datetime' => pocket_db_getNow()
    );
    return pocket_db_insert('pb_post_comments', $data, 'pb_post_comments_post_comment_id_seq');
}

/**
 *  コメント情報の承認
 *
 *  @access public
 *  @param  integer $post_comment_id    コメントID
 */
function db_update_post_comment4approve($post_comment_id)
{
    $data = array(
        'is_approved' => intval(true)
    );
    $where = array(
        'post_comment_id' => intval($post_comment_id)
    );
    return pocket_db_update('pb_post_comments', $data, $where);
}

/**
 *  コメント情報の削除
 *
 *  @access public
 *  @param  integer $post_comment_id    コメントID
 */
function db_delete_post_comment($post_comment_id)
{
    return pocket_db_delete('pb_post_comments', 'post_comment_id', $post_comment_id);
}

?>
