<?php
/**
 * Pocket Project
 * 
 * @copyright 2006 Power-Station co., Ltd, ALL Rights Reserved,
 */

/**
 *  セットアップ情報登録用のActionクラス
 *
 *  @author     Shogo Minami
 *  @access     public
 *  @package    PocketBlog.setup.do
 */
class setupAction extends Pocket_Blog_Action
{
    /**
     *  アクション実行
     *
     *  @access public
     *  @param  object  $controller         コントローラ
     *  @param  object  $request            リクエスト情報
     *  @return string  success,error
     */
    function execute(&$controller, &$request)
    {
        // リクエスト情報の取得
        $id          = $request['id'];
        $email       = $request['email'];
        $password    = $request['password'];
        $blog_name   = $request['BLOG_NAME'];
        $nickname    = $request['nickname'];
        $birth_year  = $request['birth_year'];
        $birth_month = $request['birth_month'];
        $birth_day   = $request['birth_day'];

        // セットアップファイルパスの取得、設定
        $files = $this->assignSetUpFiles();

        // 一時 create_tables ファイルの読込
        $lines = @file($files['create_tables']);

        foreach ($lines as $item)
        {
            // 文字連結
            $sql .= $item;

            if (mb_strpos($item, ";"))
            {
                // テーブルの作成
                if (DB::isError(pocket_db_query($sql)))
                    pocket_redirect('setupError.view');

                // 変数の割当解除
                unset($sql);
            }
        }

        // ブログ設定の登録
        db_insert_blog_config('BLOG_NAME', $blog_name);
        db_insert_blog_config('BLOG_INTRO', '');
        db_insert_blog_config('NEWS_SIZE', 5);
        db_insert_blog_config('PAGE_SIZE', 5);
        db_insert_blog_config('IS_COMMENT_APPROVE', intval(false));
        db_insert_blog_config('IS_COMMENT_MAIL', intval(false));
        db_insert_blog_config('IS_TRACKBACK_APPROVE', intval(false));
        db_insert_blog_config('IS_TRACKBACK_MAIL', intval(false));
        db_insert_blog_config('IS_PING_AUTO', intval(false));

        // ユーザ情報の登録
        $user_id = db_insert_userEasyProfile($id, $nickname, $birth_year, $birth_month, $birth_day);

        // メールアドレスの更新
        db_update_userEmail($user_id, pocket_encrypt($email, POCKET_BLOG_ENCRYPT_KEY));

        // パスワードの更新
        db_update_userPassword($user_id, md5($password));

        // カテゴリの登録
        db_insert_category('その他', '', 100);

        // リダイレクト
        pocket_redirect('setupComplete.view', array('email' => $email));
    }

    /**
     *  リクエスト検証
     *
     *  @access public
     *  @param  object  $validator          バリデータ
     *  @param  object  $request            リクエスト情報
     */
    function validate(&$validator, &$request)
    {
        // リクエスト情報の取得
        $id          = $request['id'];
        $email       = $request['email'];
        $password    = $request['password'];
        $blog_name   = $request['BLOG_NAME'];
        $nickname    = $request['nickname'];
        $birth_year  = $request['birth_year'];
        $birth_month = $request['birth_month'];
        $birth_day   = $request['birth_day'];

        // エラー表示用のAction名称の設定
        $this->viewAction = 'default';

        // 検証
        $validator->validate('id'         , 'ユーザID'      , $id         , 'string', true);
        $validator->validate('email'      , 'メールアドレス', $email      , 'email' , true);
        $validator->validate('password'   , 'パスワード'    , $password   , 'alnum' , true);
        $validator->validate('blog_name'  , 'ブログ名称'    , $blog_name  , 'string', true);
        $validator->validate('nickname'   , 'ニックネーム'  , $nickname   , 'string', true);
        $validator->validate('birth_year' , '生まれた年'    , $birth_year , 'number', true, 0, 9999);
        $validator->validate('birth_month', '誕生日（月）'  , $birth_month, 'number', true, 1, 12);
        $validator->validate('birth_day'  , '誕生日（日）'  , $birth_day  , 'number', true, 1, 31);

        // パスワードの桁数チェック
        if (strlen($password) < 6 || strlen($password) > 12)
        {
            $validator->addErrors('password', 'パスワードの桁数が不正です。');
        }

        // 誕生日の正当性チェック
        if ($validator->isValid() && !checkdate($birth_month, $birth_day, $birth_year))
        {
            $validator->addErrors('birth_year', '誕生日が不正です。');
        }

        // ENCRYPT_KEYの設定チェック
        if (!(defined('POCKET_BLOG_ENCRYPT_KEY') && POCKET_BLOG_ENCRYPT_KEY) || strlen(POCKET_BLOG_ENCRYPT_KEY) > 56)
        {
            $validator->addErrors('encrypt_key', '暗号化用の鍵が適切に設定されていません。config.phpの内容を確認してください。');
        }

        // DBサーバの設定チェック
        if (!$GLOBALS['_POCKET_DSN']['database'] || !$GLOBALS['_POCKET_DSN']['username'] || !$GLOBALS['_POCKET_DSN']['password'])
        {
            $validator->addErrors('database', 'データベース情報が適切に設定されていません。config.phpの内容を確認してください。');
        }

        // セットアップファイルパスの取得、設定
        $files = $this->assignSetUpFiles();

        // create_tablesファイルの存在チェック
        if (!file_exists($files['create_tables']))
        {
            $validator->addErrors('create_tables', 'create_tablesファイルが存在しません。');
        }
    }

    /**
     *  セットアップSQLファイルパスを配列に設定
     *
     *  @access public
     *  @return array
     */
    function assignSetUpFiles()
    {
        $files = array();
        
        // DB種別の判定
        if (pocket_db_isMySQL())
        {
            // MySQL用 create_tablesファイルの設定
            $files['create_tables'] = BASE_DIR . '../setup/sql/install/create_tables_mysql41_pocketblog.sql';
        }
        else
        {
            // PostgreSQL用 create_tablesファイルの設定
            $files['create_tables'] = BASE_DIR . '../setup/sql/install/create_tables_pgsql74_pocketblog.sql';
        }
        
        return $files;
    }
}

?>
